.. image:: https://cloud.githubusercontent.com/assets/5716520/24838296/a9cf5f04-1d45-11e7-855c-47b816ce1e09.png
    :target: https://coala.io/

coala.io: Linting and fixing code for all languages
---------------------------------------------------

coala provides a unified command-line interface for linting and fixing all
your code, regardless of the programming languages you use.

Please visit `coala.io <https://coala.io>`__ for an introduction to coala, to
see the supported rules and checks or to contribute!

|Linux Build Status| |Windows Build status| |Scrutinizer Code Quality|
|codecov.io| |Documentation Status| |Gitmate| |AGPL| |Chat|

.. image:: https://cloud.githubusercontent.com/assets/5716520/24838493/1c5ee0e6-1d49-11e7-9b2b-85f0c6bc2c60.png
   :alt: Awards - Yegor256 2016 Winner

.. |Chat| image:: https://badges.gitter.im/coala/coala.svg
    :target: https://coala.io/chat
.. |Linux Build Status| image:: https://img.shields.io/circleci/project/coala/coala/master.svg?label=linux%20build
   :target: https://circleci.com/gh/coala/coala
.. |Windows Build status| image:: https://img.shields.io/appveyor/ci/coala/coala/master.svg?label=windows%20build
   :target: https://ci.appveyor.com/project/coala/coala/branch/master
.. |Scrutinizer Code Quality| image:: https://img.shields.io/scrutinizer/g/coala-analyzer/coala.svg?label=scrutinizer%20quality
   :target: https://scrutinizer-ci.com/g/coala-analyzer/coala/?branch=master
.. |codecov.io| image:: https://img.shields.io/codecov/c/github/coala/coala/master.svg?label=branch%20coverage
   :target: https://codecov.io/github/coala/coala?branch=master
.. |Documentation Status| image:: https://readthedocs.org/projects/coala/badge/?version=latest
   :target: http://docs.coala.io/
.. |AGPL| image:: https://img.shields.io/github/license/coala/coala.svg
   :target: https://www.gnu.org/licenses/agpl-3.0.html
.. |Gitmate| image:: https://img.shields.io/badge/Gitmate-0%20issues-brightgreen.svg
   :target: http://gitmate.io/
